@@ -18,9 +18,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.57 2004/06/03 18:51:32 marco Exp $
+ *  $Id: ContentHandler.cpp,v 1.60.4.1 2004/09/21 11:13:21 chpe Exp $
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -47,6 +49,7 @@
 #include "ephy-embed-shell.h"
 #include "ephy-file-chooser.h"
 #include "ephy-stock-icons.h"
+#include "ephy-gui.h"
 #include "ephy-debug.h"
 #include "eel-gconf-extensions.h"
 
@@ -58,7 +61,7 @@ class GContentHandler;
 
 NS_IMPL_ISUPPORTS1(GContentHandler, nsIHelperAppLauncherDialog)
 
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 GContentHandler::GContentHandler()
 {
 	LOG ("GContentHandler ctor (%p)", this)
@@ -74,7 +77,7 @@ GContentHandler::~GContentHandler()
 {
 	LOG ("GContentHandler dtor (%p)", this)
 
-#if !MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+#ifndef MOZ_NSIMIMEINFO_NSACSTRING_
 	nsMemory::Free (mMimeType);
 #endif
 }
@@ -98,7 +101,7 @@ NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 	g_signal_emit_by_name (single, "handle_content", mMimeType.get(),
 			       mUrl.get(), &handled);
 #else
@@ -128,7 +131,7 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 {
 	EphyFileChooser *dialog;
 	gint response;
-	char *filename;
+	char *filename = NULL;
 	nsEmbedCString defaultFile;
 
 	NS_UTF16ToCString (nsEmbedString (aDefaultFile),
@@ -147,13 +150,20 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 					CONF_STATE_SAVE_DIR,
 					EPHY_FILE_FILTER_ALL);
 	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), defaultFile.get());
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	do
+	{
+		g_free (filename);
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+	} while (response == GTK_RESPONSE_ACCEPT
+		 && !ephy_gui_confirm_overwrite_file (GTK_WIDGET (dialog), filename));
 
 	if (response == GTK_RESPONSE_ACCEPT)
 	{
-		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-
 		nsCOMPtr <nsILocalFile> destFile (do_CreateInstance(NS_LOCAL_FILE_CONTRACTID));
+		NS_ENSURE_TRUE (destFile, NS_ERROR_FAILURE);
+
 		destFile->InitWithNativePath (nsEmbedCString (filename));
 		g_free (filename);
 
@@ -166,6 +176,7 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	else
 	{
 		gtk_widget_destroy (GTK_WIDGET (dialog));
+		g_free (filename);
 
 		return NS_ERROR_FAILURE;
 	}
@@ -230,7 +241,7 @@ NS_METHOD GContentHandler::Init (void)
 	mLauncher->GetMIMEInfo (getter_AddRefs(MIMEInfo));
 	NS_ENSURE_TRUE (MIMEInfo, NS_ERROR_FAILURE);
 
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 	rv = MIMEInfo->GetMIMEType (mMimeType);
 #else
 	rv = MIMEInfo->GetMIMEType (&mMimeType);
@@ -348,7 +359,7 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 
 	auto_downloads = eel_gconf_get_boolean (CONF_AUTO_DOWNLOADS);
 
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 	mHelperApp = gnome_vfs_mime_get_default_application (mMimeType.get());
 	mPermission = ephy_embed_shell_check_mime (embed_shell, mMimeType.get());
 #else
@@ -391,7 +402,7 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 		/* HACK we use the application description to ask
 		   MozDownload to open the file when download
 		   is finished */
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 		mimeInfo->SetApplicationDescription (desc);
 #else
 		mimeInfo->SetApplicationDescription (desc.get());
@@ -399,7 +410,7 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	}
 	else
 	{
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 1)
+#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 		mimeInfo->SetApplicationDescription (nsEmbedString ());
 #else
 		mimeInfo->SetApplicationDescription (nsnull);
