@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.53 2004/08/08 18:11:56 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.53.4.3 2004/09/26 16:48:26 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -124,12 +124,12 @@ EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
 	    g_ascii_strcasecmp (rel.get(), "ICON") == 0)
 	{
 		PRUnichar hrefAttr[] = { 'h', 'r', 'e', 'f', '\0' };
-		nsEmbedString value;
-		rv = linkElement->GetAttribute (nsEmbedString (hrefAttr), value);
-		if (NS_FAILED (rv) || !value.Length()) return NS_ERROR_FAILURE;
+		nsEmbedString hrefValue;
+		rv = linkElement->GetAttribute (nsEmbedString (hrefAttr), hrefValue);
+		if (NS_FAILED (rv) || !hrefValue.Length()) return NS_ERROR_FAILURE;
 
 		nsEmbedCString link;
-		NS_UTF16ToCString (value, NS_CSTRING_ENCODING_UTF8, link);
+		NS_UTF16ToCString (hrefValue, NS_CSTRING_ENCODING_UTF8, link);
 
 		nsCOMPtr<nsIDOMDocument> domDoc;
 		node->GetOwnerDocument(getter_AddRefs(domDoc));
@@ -411,7 +411,7 @@ nsresult EphyBrowser::GoToHistoryIndex (PRInt16 index)
 	return ContentNav->GotoIndex (index);
 }
 
-#if (!MOZILLA_IS_BRANCH (1, 7) || !MOZILLA_CHECK_VERSION3 (1, 7, 3)) && !MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 3)
+#ifdef GTKMOZEMBED_BROKEN_RELOAD
 /* Workaround for broken reload with frames, see mozilla bug
  * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
  */
