@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.9 2004/05/29 13:59:58 chpe Exp $
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.13.4.1 2004/09/21 11:13:21 chpe Exp $
  */
 
 /*
@@ -35,6 +35,8 @@
  *
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -91,9 +93,7 @@ public:
 	NS_DECL_ISUPPORTS
 	NS_DECL_NSIDOMWINDOWINTERNAL
 	NS_DECL_NSIDOMWINDOW
-#if MOZILLA_SNAPSHOT >= 19
 	NS_DECL_NSIDOMWINDOW2
-#endif
 
 	KeyPairHelperWindow();
 	virtual ~KeyPairHelperWindow();
@@ -101,11 +101,7 @@ public:
 	gboolean close_called;
 };
 
-#if MOZILLA_SNAPSHOT >= 19
 NS_IMPL_ISUPPORTS3(KeyPairHelperWindow, nsIDOMWindowInternal, nsIDOMWindow, nsIDOMWindow2)
-#else
-NS_IMPL_ISUPPORTS2(KeyPairHelperWindow, nsIDOMWindowInternal, nsIDOMWindow)
-#endif
 
 KeyPairHelperWindow::KeyPairHelperWindow()
 {
@@ -249,13 +245,6 @@ NS_IMETHODIMP KeyPairHelperWindow::GetWindow(nsIDOMWindowInternal * *aWindow)
     MOZ_NOT_IMPLEMENTED
 }
 
-#if MOZILLA_SNAPSHOT >= 19
-NS_IMETHODIMP KeyPairHelperWindow::GetWindowRoot(nsIDOMEventTarget * *aEvent)
-{
-    MOZ_NOT_IMPLEMENTED
-}
-#endif
-
 /* readonly attribute nsIDOMWindowInternal self; */
 NS_IMETHODIMP KeyPairHelperWindow::GetSelf(nsIDOMWindowInternal * *aSelf)
 {
@@ -719,4 +708,9 @@ NS_IMETHODIMP KeyPairHelperWindow::SizeToContent()
     MOZ_NOT_IMPLEMENTED
 }
 
+NS_IMETHODIMP KeyPairHelperWindow::GetWindowRoot(nsIDOMEventTarget * *aWindowRoot)
+{
+    MOZ_NOT_IMPLEMENTED
+}
+
 #endif
