@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.92 2004/08/19 17:48:43 marco Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.92.4.2 2004/09/25 13:23:48 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -26,7 +26,6 @@
 #endif
 
 #include "mozilla-embed-single.h"
-#include "mozilla-version.h"
 
 #include "ephy-cookie-manager.h"
 #include "ephy-password-manager.h"
@@ -72,9 +71,14 @@
 #include <nsIPassword.h>
 #endif
 
+#if defined (HAVE_CHROME_NSICHROMEREGISTRYSEA_H)
+#include <chrome/nsIChromeRegistrySea.h>
+#elif defined(MOZ_NSIXULCHROMEREGISTRY_SELECTSKIN)
+#include <nsIChromeRegistry.h>
+#endif
+
 #ifdef ALLOW_PRIVATE_API
 // FIXME: For setting the locale. hopefully gtkmozembed will do itself soon
-#include <nsIChromeRegistry.h>
 #include <nsILocaleService.h>
 #include <nsIHttpAuthManager.h>
 #include <nsICacheService.h>
@@ -404,10 +408,16 @@ getUILang (nsAString& aUILang)
 static nsresult
 mozilla_init_chrome (void)
 {
+/* FIXME: can we just omit this on new-toolkit ? */
+#if defined(MOZ_NSIXULCHROMEREGISTRY_SELECTSKIN) || defined(HAVE_CHROME_NSICHROMEREGISTRYSEA_H)
 	nsresult rv;
 	nsEmbedString uiLang;
 
+#ifdef HAVE_CHROME_NSICHROMEREGISTRYSEA_H
+	nsCOMPtr<nsIChromeRegistrySea> chromeRegistry = do_GetService (NS_CHROMEREGISTRY_CONTRACTID);
+#else
 	nsCOMPtr<nsIXULChromeRegistry> chromeRegistry = do_GetService (NS_CHROMEREGISTRY_CONTRACTID);
+#endif
 	NS_ENSURE_TRUE (chromeRegistry, NS_ERROR_FAILURE);
 
 	// Set skin to 'classic' so we get native scrollbars.
@@ -425,6 +435,9 @@ mozilla_init_chrome (void)
 	NS_UTF16ToCString (uiLang, NS_CSTRING_ENCODING_UTF8, cUILang);
 
 	return chromeRegistry->SelectLocale (cUILang, PR_FALSE);
+#else
+	return NS_OK;
+#endif
 }
 
 static void
