@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-notifiers.cpp,v 1.51 2004/07/30 19:56:08 chpe Exp $
+ *  $Id: mozilla-notifiers.cpp,v 1.51.4.2 2004/09/26 16:48:26 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -25,8 +25,6 @@
 #include "config.h"
 #endif
 
-#include "mozilla-version.h"
-
 #include "ephy-embed-single.h"
 #include "ephy-embed-shell.h"
 #include "mozilla-notifiers.h"
@@ -370,7 +368,7 @@ mozilla_proxy_autoconfig_notifier (GConfClient *client,
 	char *url = eel_gconf_get_string (entry->key);
 	if (url && url[0] != '\0')
 	{
-#if MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 2)
+#ifdef MOZ_NSIPROTOCOLPROXYSERVICE_NSACSTRING_
 	        pps->ConfigureFromPAC (nsEmbedCString (url));
 #else
 	        pps->ConfigureFromPAC (url);
@@ -759,7 +757,7 @@ get_system_language ()
 
 	if (sys_langs)
 	{
-		char *lang = (char *)sys_langs->data;
+		lang = (char *)sys_langs->data;
 
 		/* FIXME this probably need to be smarter */
 		/* FIXME this can be up to 8 chars, not just 2 */
