@@ -15,15 +15,23 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.66.4.2 2004/08/23 12:45:47 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.71 2004/08/23 12:42:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
+#include <gtk/gtkradioaction.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkalignment.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkhpaned.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkclipboard.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkhbox.h>
@@ -1266,10 +1274,14 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	ephy_node_view_add_column (EPHY_NODE_VIEW (sites_view), _("Sites"),
 				   G_TYPE_STRING,
 				   EPHY_NODE_PAGE_PROP_TITLE,
-				   EPHY_NODE_PAGE_PROP_PRIORITY,
-				   EPHY_NODE_VIEW_AUTO_SORT |
-				   EPHY_NODE_VIEW_SEARCHABLE,
+				   EPHY_NODE_VIEW_SEARCHABLE |
+				   EPHY_NODE_VIEW_SHOW_PRIORITY,
 				   provide_favicon);
+	ephy_node_view_set_priority (EPHY_NODE_VIEW (sites_view),
+				     EPHY_NODE_PAGE_PROP_PRIORITY);
+	ephy_node_view_set_sort (EPHY_NODE_VIEW (sites_view), G_TYPE_STRING,
+				 EPHY_NODE_PAGE_PROP_TITLE,
+				 GTK_SORT_ASCENDING);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), sites_view);
 	gtk_widget_show (sites_view);
 	editor->priv->sites_view = sites_view;
@@ -1319,15 +1331,18 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 				           n_page_drag_types, col_id);
 	col = ephy_node_view_add_column (EPHY_NODE_VIEW (pages_view), _("Title"),
 				         G_TYPE_STRING, EPHY_NODE_PAGE_PROP_TITLE,
-				         -1, EPHY_NODE_VIEW_USER_SORT |
+				         EPHY_NODE_VIEW_SORTABLE |
 					 EPHY_NODE_VIEW_SEARCHABLE, NULL);
 	gtk_tree_view_column_set_max_width (col, 250);
 	editor->priv->title_col = col;
 	col = ephy_node_view_add_column (EPHY_NODE_VIEW (pages_view), _("Address"),
 				         G_TYPE_STRING, EPHY_NODE_PAGE_PROP_LOCATION,
-				         -1, EPHY_NODE_VIEW_USER_SORT, NULL);
+				         EPHY_NODE_VIEW_SORTABLE, NULL);
 	gtk_tree_view_column_set_max_width (col, 200);
 	editor->priv->address_col = col;
+	ephy_node_view_set_sort (EPHY_NODE_VIEW (pages_view), G_TYPE_INT,
+				 EPHY_NODE_PAGE_PROP_LAST_VISIT,
+				 GTK_SORT_DESCENDING);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), pages_view);
 	gtk_widget_show (pages_view);
 	editor->priv->pages_view = pages_view;
