@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.110 2004/07/31 17:37:07 adamh Exp $
+ *  $Id: ephy-tab.c,v 1.112 2004/08/08 11:32:18 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -551,7 +551,7 @@ popups_manager_show (PopupInfo *popup,
 	single = EPHY_EMBED_SINGLE
 		(ephy_embed_shell_get_embed_single (embed_shell));
 
-	ephy_embed_single_open_window (single, embed, popup->url,
+	ephy_embed_single_open_window (single, embed, popup->url, "",
 				       popup->features);
 
 	popups_manager_free_info (popup);
@@ -1262,7 +1262,7 @@ ephy_tab_new_window_cb (EphyEmbed *embed, EphyEmbed **new_embed,
 	new_tab = ephy_tab_new ();
 	gtk_widget_show (GTK_WIDGET (new_tab));
 
-        ephy_window_add_tab (window, new_tab, EPHY_NOTEBOOK_ADD_LAST, FALSE);
+        ephy_window_add_tab (window, new_tab, -1, FALSE);
 
 	*new_embed = ephy_tab_get_embed (new_tab);
 
