@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.201 2004/07/19 08:27:06 marco Exp $
+ *  $Id: ephy-window.c,v 1.206.4.1 2004/09/26 16:48:26 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -180,7 +180,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "ViewZoomOut", GTK_STOCK_ZOOM_OUT, N_("Zoom _Out"), "<control>minus",
 	  N_("Decrease the text size"),
 	  G_CALLBACK (window_cmd_view_zoom_out) },
-	{ "ViewZoomNormal", GTK_STOCK_ZOOM_100, N_("_Normal Size"), NULL,
+	{ "ViewZoomNormal", GTK_STOCK_ZOOM_100, N_("_Normal Size"), "<control>0",
 	  N_("Use the normal text size"),
 	  G_CALLBACK (window_cmd_view_zoom_normal) },
 	{ "ViewEncoding", NULL, N_("Text _Encoding"), NULL,
@@ -379,9 +379,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_window_get_type (void)
 {
-        static GType ephy_window_type = 0;
+        static GType type = 0;
 
-        if (ephy_window_type == 0)
+        if (type == 0)
         {
                 static const GTypeInfo our_info =
                 {
@@ -396,45 +396,12 @@ ephy_window_get_type (void)
                         (GInstanceInitFunc) ephy_window_init
                 };
 
-                ephy_window_type = g_type_register_static (GTK_TYPE_WINDOW,
-							   "EphyWindow",
-							   &our_info, 0);
+                type = g_type_register_static (GTK_TYPE_WINDOW,
+					       "EphyWindow",
+					       &our_info, 0);
         }
-        return ephy_window_type;
-}
 
-static void
-ephy_window_destroy (GtkObject *gtkobject)
-{
-	EphyWindow *window = EPHY_WINDOW (gtkobject);
-
-	LOG ("EphyWindow destroy %p", window)
-
-	if (window->priv->closing == FALSE)
-	{
-		EphyExtension *manager;
-
-		window->priv->closing = TRUE;
-
-		/* Let the extensions detach themselves from the window */
-		manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
-		ephy_extension_detach_window (manager, window);
-	}
-
-	if (window->priv->exit_fullscreen_popup)
-	{
-		gtk_widget_destroy (window->priv->exit_fullscreen_popup);
-		window->priv->exit_fullscreen_popup = NULL;
-	}
-
-        GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
-}
-
-static void
-add_widget (GtkUIManager *merge, GtkWidget *widget, EphyWindow *window)
-{
-	gtk_box_pack_start (GTK_BOX (window->priv->menu_dock),
-			    widget, FALSE, FALSE, 0);
+        return type;
 }
 
 static void
@@ -448,6 +415,7 @@ update_exit_fullscreen_popup_position (EphyWindow *window)
 
 	gtk_window_get_size (GTK_WINDOW (popup), &popup_width, &popup_height);
 
+	/* FIXME multihead */
 	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
                         gdk_screen_get_monitor_at_window
                         (gdk_screen_get_default (),
@@ -468,11 +436,57 @@ update_exit_fullscreen_popup_position (EphyWindow *window)
 }
 
 static void
-size_changed_cb (GdkScreen *screen, EphyWindow *window)
+screen_size_changed_cb (GdkScreen *screen,
+			EphyWindow *window)
 {
 	update_exit_fullscreen_popup_position (window);
 }
 
+static void
+destroy_exit_fullscreen_popup (EphyWindow *window)
+{
+	if (window->priv->exit_fullscreen_popup != NULL)
+	{
+		/* FIXME multihead */
+		g_signal_handlers_disconnect_by_func
+			(gdk_screen_get_default (),
+			 G_CALLBACK (screen_size_changed_cb), window);
+
+		gtk_widget_destroy (window->priv->exit_fullscreen_popup);
+		window->priv->exit_fullscreen_popup = NULL;
+	}
+}
+
+static void
+ephy_window_destroy (GtkObject *gtkobject)
+{
+	EphyWindow *window = EPHY_WINDOW (gtkobject);
+
+	LOG ("EphyWindow destroy %p", window)
+
+	if (window->priv->closing == FALSE)
+	{
+		EphyExtension *manager;
+
+		window->priv->closing = TRUE;
+
+		/* Let the extensions detach themselves from the window */
+		manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
+		ephy_extension_detach_window (manager, window);
+	}
+
+	destroy_exit_fullscreen_popup (window);
+
+        GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
+}
+
+static void
+add_widget (GtkUIManager *merge, GtkWidget *widget, EphyWindow *window)
+{
+	gtk_box_pack_start (GTK_BOX (window->priv->menu_dock),
+			    widget, FALSE, FALSE, 0);
+}
+
 static void
 exit_fullscreen_button_clicked_cb (GtkWidget *button, EphyWindow *window)
 {
@@ -566,14 +580,16 @@ ephy_window_fullscreen (EphyWindow *window)
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
+	gtk_window_set_resizable (GTK_WINDOW (popup), FALSE);
+
+	/* FIXME multihead */
+	g_signal_connect (gdk_screen_get_default (), "size-changed",
+			  G_CALLBACK (screen_size_changed_cb), window);
+
 	update_exit_fullscreen_popup_position (window);
 
 	gtk_widget_show (popup);
 
-	g_signal_connect (G_OBJECT (gdk_screen_get_default ()),
-                          "size-changed", G_CALLBACK (size_changed_cb),
-			  window);
-
 	egg_editable_toolbar_set_model
 		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
 		 EGG_TOOLBARS_MODEL (
@@ -585,15 +601,7 @@ ephy_window_unfullscreen (EphyWindow *window)
 {
 	window->priv->mode = EPHY_WINDOW_MODE_NORMAL;
 
-	if (window->priv->exit_fullscreen_popup != NULL)
-	{
-		g_signal_handlers_disconnect_by_func (G_OBJECT (gdk_screen_get_default ()),
-						      G_CALLBACK (size_changed_cb),
-						      window);
-
-		gtk_widget_destroy (window->priv->exit_fullscreen_popup);
-		window->priv->exit_fullscreen_popup = NULL;
-	}
+	destroy_exit_fullscreen_popup (window);
 
 	egg_editable_toolbar_set_model
 		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
@@ -958,7 +966,7 @@ connect_proxy_cb (GtkUIManager *manager,
 static void
 update_chromes_actions (EphyWindow *window)
 {
-	GtkActionGroup *action_group = GTK_ACTION_GROUP (window->priv->action_group);
+	GtkActionGroup *action_group = window->priv->action_group;
 	GtkAction *action;
 	gboolean show_statusbar, show_menubar, show_toolbar, show_bookmarksbar;
 
@@ -997,8 +1005,8 @@ update_chromes_actions (EphyWindow *window)
 static void
 update_actions_sensitivity (EphyWindow *window)
 {
-	GtkActionGroup *action_group = GTK_ACTION_GROUP (window->priv->action_group);
-	GtkActionGroup *popups_action_group = GTK_ACTION_GROUP (window->priv->popups_action_group);
+	GtkActionGroup *action_group = window->priv->action_group;
+	GtkActionGroup *popups_action_group = window->priv->popups_action_group;
 	GtkAction *action;
 	gboolean bookmarks_editable, save_to_disk;
 	gboolean printing, print_setup, fullscreen;
@@ -1031,6 +1039,8 @@ update_actions_sensitivity (EphyWindow *window)
 	save_to_disk = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_SAVE_TO_DISK);
 	action = gtk_action_group_get_action (action_group, "FileSaveAs");
 	g_object_set (action, "sensitive", save_to_disk, NULL);
+	action = gtk_action_group_get_action (action_group, "FileSave");
+	g_object_set (action, "sensitive", save_to_disk, NULL);
 	action = gtk_action_group_get_action (popups_action_group, "DownloadLink");
 	g_object_set (action, "sensitive", save_to_disk, NULL);
 	action = gtk_action_group_get_action (popups_action_group, "SaveBackgroundAs");
@@ -1526,9 +1536,12 @@ popup_menu_at_coords (GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 
 static void
 hide_embed_popup_cb (GtkWidget *popup,
-			EphyWindow *window)
+		     EphyWindow *window)
 {
 	enable_edit_actions_sensitivity (window);
+
+	g_signal_handlers_disconnect_by_func
+		(popup, G_CALLBACK (hide_embed_popup_cb), window);
 }
 
 static void
@@ -2134,6 +2147,7 @@ ephy_window_init (EphyWindow *window)
 {
 	EphyExtension *manager;
 	EphyEmbedSingle *single;
+	EggToolbarsModel *model;
 
 	LOG ("EphyWindow initialising %p", window)
 
@@ -2177,6 +2191,13 @@ ephy_window_init (EphyWindow *window)
 	window->priv->enc_menu = ephy_encoding_menu_new (window);
 	window->priv->bmk_menu = ephy_bookmarks_menu_new (window);
 
+	/* get the toolbars model *before* getting the bookmarksbar model
+	 * (via ephy_bookmarsbar_new()), so that the toolbars model is
+	 * instantiated *before* the bookmarksbarmodel, to make forwarding
+	 * works. See bug #151267.
+	 */
+	model= EGG_TOOLBARS_MODEL (ephy_shell_get_toolbars_model (ephy_shell, FALSE));
+
 	/* create the toolbars */
 	window->priv->toolbar = toolbar_new (window);
 	window->priv->bookmarksbar = ephy_bookmarksbar_new (window);
@@ -2207,9 +2228,7 @@ ephy_window_init (EphyWindow *window)
 	 * the toolbar
 	 */
 	egg_editable_toolbar_set_model
-		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
-		 EGG_TOOLBARS_MODEL
-			 (ephy_shell_get_toolbars_model (ephy_shell, FALSE)));
+		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar), model);
 
 	g_signal_connect (window, "window-state-event",
 			  G_CALLBACK (ephy_window_state_event_cb),
@@ -2784,12 +2803,13 @@ ephy_window_set_zoom (EphyWindow *window,
 }
 
 void
-ephy_window_load_in_tabs (EphyWindow *window, EphyTab *tab, GList *uri_list)
+ephy_window_load_in_tabs (EphyWindow *window,
+			  EphyTab *tab,
+			  GList *uri_list)
 {
 	EphyEmbed *embed = NULL;
 	GList *l;
 	guint num = 0;
-	GnomeVFSURI *uri;
 
 	if (tab != NULL)
 	{
@@ -2800,10 +2820,7 @@ ephy_window_load_in_tabs (EphyWindow *window, EphyTab *tab, GList *uri_list)
 	l = uri_list;
 	while (l != NULL && num < INSANE_NUMBER_OF_URLS)
 	{
-		gchar *url = NULL;
-
-		uri = (GnomeVFSURI*) l->data;
-		url = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+		const char *url = l->data;
 
 		if (num == 0 && embed != NULL)
 		{
@@ -2823,8 +2840,6 @@ ephy_window_load_in_tabs (EphyWindow *window, EphyTab *tab, GList *uri_list)
 							 EPHY_NEW_TAB_APPEND_LAST));
 		}
 
-		g_free (url);
-		url = NULL;
 		l = l->next;
 		++num;
 	}
